"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.parse = parse;

var _orga = require("orga");

var _traverse = _interopRequireDefault(require("traverse"));

var _structuredSource = _interopRequireDefault(require("structured-source"));

var _mapping = require("./mapping");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function removeUnusedProperties(node) {
  if (_typeof(node) !== 'object') {
    return;
  }

  delete node.position;
}

function parse(org) {
  var ast = (0, _orga.parse)(org);
  var src = new _structuredSource["default"](org);
  var tr = (0, _traverse["default"])(ast);
  tr.forEach(function (node) {
    if (this.notLeaf) {
      delete node.parent; // AST node has type and position

      if (node.type && node.position) {
        node.type = _mapping.nodeTypes[node.type];
      }

      if (typeof node.type === 'undefined') {
        node.type = 'UNKNOWN';
      } // map `range`, `loc` and `raw` to node


      if (_typeof(node.position) === 'object') {
        var position = node.position; // TxtNode's line start with 1
        // TxtNode's column start with 0

        var positionCompensated = {
          start: {
            line: position.start.line,
            column: position.start.column - 1
          },
          end: {
            line: position.end.line,
            column: position.end.column - 1
          }
        };
        var range = src.locationToRange(positionCompensated);
        node.loc = positionCompensated;
        node.range = range;
        node.raw = org.slice(range[0], range[1]);
      } // map `url` to Link node


      if (node.type === 'Link' && typeof node.value !== 'undefined') {
        node.url = node.value;
      }
    }

    removeUnusedProperties(node);
  });
  return ast;
}
//# sourceMappingURL=org-to-ast.js.map